@@ -29,6 +29,7 @@
 #include <QDateTime>
 #include <QTimeZone>
 #include <QTimer>
+#include <QDebug>
 
 #include <unistd.h>
 
@@ -280,7 +281,7 @@ void TestMetaWeblog::errorPost(KBlog::Blog::ErrorType type, const QString &errSt
         break;
     };
     qDebug() << "error: " << errStr;
-    if (post != 0) {
+    if (post != nullptr) {
         dumpPost(post);
     }
     qDebug() << "#############################\n";
